[![Build Status](https://dev.azure.com/marekbf3/nnlab/_apis/build/status/pekalam.ml_commons?branchName=master)](https://dev.azure.com/marekbf3/nnlab/_build/latest?definitionId=11&branchName=master)
ml_commons
